ASN1DERDecoder class

Constructors

ASN1DERDecoder()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode({required List<int> data}) → List<ASN1Object>
decodeOid({required List<int> contentData}) → String?
Decode DER OID bytes to String with dot notation
generalizedTimeToDate({required List<int> contentData}) → DateTime?
Converts a GeneralizedTime value to a date.
getContentLength({required Iterator<int> iterator}) → BigInt
loadSubContent({required Iterator<int> iterator}) → List<int>
parse({required Iterator<int> iterator}) → List<ASN1Object>
sequenceContent({required List<int> data}) → List<int>
utcTimeToDate({required List<int> contentData}) → DateTime?
Converts a UTCTime value to a date.