ASN1Identifier class

Constructors

ASN1Identifier(int rawValue)

Properties

description → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
rawValue ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isConstructed() → bool
isPrimitive() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
tagNumber() → ASN1IdentifierTagNumber
toString() → String
A string representation of this object.
override
typeClass() → ASN1IdentifierClass

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

constructedTag ↔ int
getter/setter pair