ASN1Object class

Constructors

ASN1Object()

Properties

asString → String?
no setter
description → String
no setter
encoded ↔ Uint8List?
This property contains the DER encoded object
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
identifier ↔ ASN1Identifier?
getter/setter pair
parent ↔ ASN1Object?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sub ↔ List<ASN1Object>?
getter/setter pair
value ↔ dynamic
This property contains the decoded object whenever is possible
getter/setter pair

Methods

atIndex(X509BlockPosition x509blockPosition) → ASN1Object?
findOid({OID? oid, String? oidValue}) → ASN1Object?
firstSub() → ASN1Object?
lastSub() → ASN1Object?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printAsn1({dynamic insets = ""}) → String
subAtIndex(int index) → ASN1Object?
subCount() → int
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited