AndroidWebStorageOrigin class

Class that encapsulates information about the amount of storage currently used by an origin for the JavaScript storage APIs. An origin comprises the host, scheme and port of a URI. See AndroidWebStorageManager for details. Use WebStorageOrigin instead.

Annotations

Constructors

AndroidWebStorageOrigin({String? origin, int? quota, int? usage})

Properties

hashCode → int
The hash code for this object.
no setterinherited
origin ↔ String?
The string representation of this origin.
getter/setter pair
quota ↔ int?
The quota for this origin, for the Web SQL Database API, in bytes.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
usage ↔ int?
The total amount of storage currently being used by this origin, for all JavaScript storage APIs, in bytes.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts instance to a map.
toMap() → Map<String, dynamic>
Converts instance to a map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic>? map) → AndroidWebStorageOrigin?
Gets a possible AndroidWebStorageOrigin instance from a Map value.