AuthorityKeyIdentifierExtension class

Recognition for Authority Key Identifier Extension (2.5.29.35)

Inheritance

Constructors

AuthorityKeyIdentifierExtension({required dynamic block})

Properties

alternativeNameAsStrings → List<String>
no setterinherited
block ↔ ASN1Object?
getter/setter pairinherited
certificateIssuer → List<String>?
no setter
hashCode → int
The hash code for this object.
no setterinherited
isCritical → bool
no setterinherited
keyIdentifier → List<int>?
AuthorityKeyIdentifier ::= SEQUENCE { keyIdentifier 0 KeyIdentifier OPTIONAL, authorityCertIssuer 1 GeneralNames OPTIONAL, authorityCertSerialNumber 2 CertificateSerialNumber OPTIONAL }
no setter
name → String?
no setterinherited
oid → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serialNumber → List<int>?
no setter
value → dynamic
no setterinherited
valueAsBlock → ASN1Object?
no setterinherited
valueAsStrings → List<String>
no setterinherited

Methods

generalName({required ASN1Object item}) → String?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited