ClientCertResponse class

Class that represents the response used by the PlatformWebViewCreationParams.onReceivedClientCertRequest event.

Constructors

ClientCertResponse({required String certificatePath, String? certificatePassword = "", @Deprecated('Use keyStoreType instead') String? androidKeyStoreType = "PKCS12", String? keyStoreType = "PKCS12", ClientCertResponseAction? action = ClientCertResponseAction.CANCEL})

Properties

action ↔ ClientCertResponseAction?
Indicate the ClientCertResponseAction to take in response of the client certificate challenge.
getter/setter pair
androidKeyStoreType ↔ String?
Use keyStoreType instead.
getter/setter pair
certificatePassword ↔ String?
The certificate password.
getter/setter pair
certificatePath ↔ String
The file path of the certificate to use.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
keyStoreType ↔ String?
An Android-specific property used by Java KeyStore class to get the instance.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts instance to a map.
toMap() → Map<String, dynamic>
Converts instance to a map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic>? map) → ClientCertResponse?
Gets a possible ClientCertResponse instance from a Map value.