ClientCertResponseAction class

Class used by ClientCertResponse class.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int
Gets int native value.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

values → Set<ClientCertResponseAction>
Set of all values of ClientCertResponseAction.
final

Static Methods

fromNativeValue(int? value) → ClientCertResponseAction?
Gets a possible ClientCertResponseAction instance from a native value.
fromValue(int? value) → ClientCertResponseAction?
Gets a possible ClientCertResponseAction instance from int value.

Constants

CANCEL → const ClientCertResponseAction
Cancel this request.
IGNORE → const ClientCertResponseAction
Ignore the request for now.
PROCEED → const ClientCertResponseAction
Proceed with the specified certificate.