ConsoleMessage class

Class representing a JavaScript console message from WebCore. This could be a issued by a call to one of the console logging functions (e.g. console.log('...')) or a JavaScript error on the page.

To receive notifications of these messages, use the PlatformWebViewCreationParams.onConsoleMessage event.

Constructors

ConsoleMessage({String message = "", ConsoleMessageLevel messageLevel = ConsoleMessageLevel.LOG})

Properties

hashCode → int
The hash code for this object.
no setterinherited
message ↔ String
Console message
getter/setter pair
messageLevel ↔ ConsoleMessageLevel
Console message level
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts instance to a map.
toMap() → Map<String, dynamic>
Converts instance to a map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic>? map) → ConsoleMessage?
Gets a possible ConsoleMessage instance from a Map value.