ContentBlockerTriggerLoadType class

Class that represents the possible load type for a ContentBlockerTrigger.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → String
Gets String native value.
toString() → String
A string representation of this object.
override
toValue() → String
Gets String value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

values → Set<ContentBlockerTriggerLoadType>
Set of all values of ContentBlockerTriggerLoadType.
final

Static Methods

fromNativeValue(String? value) → ContentBlockerTriggerLoadType?
Gets a possible ContentBlockerTriggerLoadType instance from a native value.
fromValue(String? value) → ContentBlockerTriggerLoadType?
Gets a possible ContentBlockerTriggerLoadType instance from String value.

Constants

FIRST_PARTY → const ContentBlockerTriggerLoadType
FIRST_PARTY is triggered only if the resource has the same scheme, domain, and port as the main page resource.
THIRD_PARTY → const ContentBlockerTriggerLoadType
THIRD_PARTY is triggered if the resource is not from the same domain as the main page resource.