ContextMenuOptions class

Use ContextMenuSettings instead.

Annotations

Constructors

ContextMenuOptions({bool hideDefaultSystemContextMenuItems = false})

Properties

hashCode → int
The hash code for this object.
no setterinherited
hideDefaultSystemContextMenuItems ↔ bool
Whether all the default system context menu items should be hidden or not. The default value is false.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited