CustomTabsNavigationEventType class

The type corresponding to the navigation event of PlatformChromeSafariBrowserEvents.onNavigationEvent.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int?
Gets int? native value.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

ABORTED → CustomTabsNavigationEventType
Sent when loading was aborted by a user action before it finishes like clicking on a link or refreshing the page.
final
FAILED → CustomTabsNavigationEventType
Sent when the tab couldn't finish loading due to a failure.
final
FINISHED → CustomTabsNavigationEventType
Sent when the tab has finished loading a page.
final
STARTED → CustomTabsNavigationEventType
Sent when the tab has started loading a page.
final
TAB_HIDDEN → CustomTabsNavigationEventType
Sent when the tab becomes hidden.
final
TAB_SHOWN → CustomTabsNavigationEventType
Sent when the tab becomes visible.
final
values → Set<CustomTabsNavigationEventType>
Set of all values of CustomTabsNavigationEventType.
final

Static Methods

fromNativeValue(int? value) → CustomTabsNavigationEventType?
Gets a possible CustomTabsNavigationEventType instance from a native value.
fromValue(int? value) → CustomTabsNavigationEventType?
Gets a possible CustomTabsNavigationEventType instance from int value.