CustomTabsPostMessageResultType class

Custom Tabs postMessage result type.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int?
Gets int? native value.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

FAILURE_DISALLOWED → CustomTabsPostMessageResultType
Indicates that the postMessage request was not allowed due to a bad argument or requesting at a disallowed time like when in background.
final
FAILURE_MESSAGING_ERROR → CustomTabsPostMessageResultType
Indicates that the postMessage request has failed due to an internal error on the browser message channel.
final
FAILURE_REMOTE_ERROR → CustomTabsPostMessageResultType
Indicates that the postMessage request has failed due to a RemoteException.
final
SUCCESS → CustomTabsPostMessageResultType
Indicates that the postMessage request was accepted.
final
values → Set<CustomTabsPostMessageResultType>
Set of all values of CustomTabsPostMessageResultType.
final

Static Methods

fromNativeValue(int? value) → CustomTabsPostMessageResultType?
Gets a possible CustomTabsPostMessageResultType instance from a native value.
fromValue(int? value) → CustomTabsPostMessageResultType?
Gets a possible CustomTabsPostMessageResultType instance from int value.