CustomTabsRelationType class

Custom Tabs relation for which the result is available.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int?
Gets int? native value.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

HANDLE_ALL_URLS → CustomTabsRelationType
Requests the ability to handle all URLs from a given origin.
final
USE_AS_ORIGIN → CustomTabsRelationType
For App -> Web transitions, requests the app to use the declared origin to be used as origin for the client app in the web APIs context.
final
values → Set<CustomTabsRelationType>
Set of all values of CustomTabsRelationType.
final

Static Methods

fromNativeValue(int? value) → CustomTabsRelationType?
Gets a possible CustomTabsRelationType instance from a native value.
fromValue(int? value) → CustomTabsRelationType?
Gets a possible CustomTabsRelationType instance from int value.