DismissButtonStyle class

Class used to set the custom style for the dismiss button.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int
Gets int native value.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

values → Set<DismissButtonStyle>
Set of all values of DismissButtonStyle.
final

Static Methods

fromNativeValue(int? value) → DismissButtonStyle?
Gets a possible DismissButtonStyle instance from a native value.
fromValue(int? value) → DismissButtonStyle?
Gets a possible DismissButtonStyle instance from int value.

Constants

CANCEL → const DismissButtonStyle
Makes the button title the localized string "Cancel".
CLOSE → const DismissButtonStyle
Makes the button title the localized string "Close".
DONE → const DismissButtonStyle
Makes the button title the localized string "Done".