FetchRequestAction class

Class used by FetchRequest class.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int
Gets int native value.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

values → Set<FetchRequestAction>
Set of all values of FetchRequestAction.
final

Static Methods

fromNativeValue(int? value) → FetchRequestAction?
Gets a possible FetchRequestAction instance from a native value.
fromValue(int? value) → FetchRequestAction?
Gets a possible FetchRequestAction instance from int value.

Constants

ABORT → const FetchRequestAction
Aborts the fetch request.
PROCEED → const FetchRequestAction
Proceeds with the fetch request.