FetchRequestCredentialDefault class

Class that represents the default credentials used by an FetchRequest.

Inheritance

Constructors

FetchRequestCredentialDefault({String? value, String? type})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
Type of credentials.
getter/setter pairinherited
value ↔ String?
The value of the credentials.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts instance to a map.
override
toMap() → Map<String, dynamic>
Converts instance to a map.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic>? map) → FetchRequestCredentialDefault?
Gets a possible FetchRequestCredentialDefault instance from a Map value.
override