FetchRequestPasswordCredential class

Class that represents a PasswordCredential type of credentials.

Inheritance

Constructors

FetchRequestPasswordCredential({WebUri? iconURL, dynamic id, String? name, String? password, String? type})

Properties

hashCode → int
The hash code for this object.
no setterinherited
iconURL ↔ WebUri?
URL pointing to an image for an icon. This image is intended for display in a credential chooser. The URL must be accessible without authentication.
getter/setter pair
id ↔ dynamic
Credential's identifier.
getter/setter pair
name ↔ String?
The name associated with a credential. It should be a human-readable, public name.
getter/setter pair
password ↔ String?
The password of the credential.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
Type of credentials.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts instance to a map.
override
toMap() → Map<String, dynamic>
Converts instance to a map.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic>? map) → FetchRequestPasswordCredential?
Gets a possible FetchRequestPasswordCredential instance from a Map value.
override