FrameInfo class

An object that contains information about a frame on a webpage.

Constructors

FrameInfo({required bool isMainFrame, URLRequest? request, SecurityOrigin? securityOrigin})

Properties

hashCode → int
The hash code for this object.
no setterinherited
isMainFrame ↔ bool
A Boolean value indicating whether the frame is the web site's main frame or a subframe.
getter/setter pair
request ↔ URLRequest?
The frame’s current request.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securityOrigin ↔ SecurityOrigin?
The frame’s security origin.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts instance to a map.
toMap() → Map<String, dynamic>
Converts instance to a map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic>? map) → FrameInfo?
Gets a possible FrameInfo instance from a Map value.