IOSInAppBrowserOptions class

This class represents all the iOS-only PlatformInAppBrowser options available. Use InAppBrowserSettings instead.

Implemented types
Annotations

Constructors

IOSInAppBrowserOptions({bool toolbarTopTranslucent = true, Color? toolbarTopTintColor, bool hideToolbarBottom = false, Color? toolbarBottomBackgroundColor, Color? toolbarBottomTintColor, bool toolbarBottomTranslucent = true, String? closeButtonCaption, Color? closeButtonColor, IOSUIModalPresentationStyle presentationStyle = IOSUIModalPresentationStyle.FULL_SCREEN, IOSUIModalTransitionStyle transitionStyle = IOSUIModalTransitionStyle.COVER_VERTICAL})

Properties

closeButtonCaption ↔ String?
Set the custom text for the close button.
getter/setter pair
closeButtonColor ↔ Color?
Set the custom color for the close button.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hideToolbarBottom ↔ bool
Set to true to hide the toolbar at the bottom of the WebView. The default value is false.
getter/setter pair
presentationStyle ↔ IOSUIModalPresentationStyle
Set the custom modal presentation style when presenting the WebView. The default value is IOSUIModalPresentationStyle.FULL_SCREEN.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toolbarBottomBackgroundColor ↔ Color?
Set the custom background color of the toolbar at the bottom.
getter/setter pair
toolbarBottomTintColor ↔ Color?
Set the tint color to apply to the bar button items.
getter/setter pair
toolbarBottomTranslucent ↔ bool
Set to true to set the toolbar at the bottom translucent. The default value is true.
getter/setter pair
toolbarTopBarTintColor ↔ Color?
Set the tint color to apply to the navigation bar background.
getter/setter pair
toolbarTopTintColor ↔ Color?
Set the tint color to apply to the navigation items and bar button items.
getter/setter pair
toolbarTopTranslucent ↔ bool
Set to true to set the toolbar at the top translucent. The default value is true.
getter/setter pair
transitionStyle ↔ IOSUIModalTransitionStyle
Set to the custom transition style when presenting the WebView. The default value is IOSUIModalTransitionStyle.COVER_VERTICAL.
getter/setter pair

Methods

copy() → IOSInAppBrowserOptions
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic> map) → IOSInAppBrowserOptions
override