IOSNSAttributedString class

An iOS-specific class that represents a string with associated attributes used by the PlatformPullToRefreshController and PullToRefreshOptions classes. Use AttributedString instead.

Annotations

Constructors

IOSNSAttributedString({Color? backgroundColor, double? baselineOffset, double? expansion, Color? foregroundColor, double? kern, int? ligature, double? obliqueness, Color? strikethroughColor, IOSNSUnderlineStyle? strikethroughStyle, required String string, Color? strokeColor, double? strokeWidth, IOSNSAttributedStringTextEffectStyle? textEffect, Color? underlineColor, IOSNSUnderlineStyle? underlineStyle})

Properties

backgroundColor ↔ Color?
The color of the background behind the text.
getter/setter pair
baselineOffset ↔ double?
The vertical offset for the position of the text.
getter/setter pair
expansion ↔ double?
The expansion factor of the text.
getter/setter pair
foregroundColor ↔ Color?
The color of the text.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kern ↔ double?
The kerning of the text.
getter/setter pair
ligature ↔ int?
The ligature of the text.
getter/setter pair
obliqueness ↔ double?
The obliqueness of the text.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strikethroughColor ↔ Color?
The color of the strikethrough.
getter/setter pair
strikethroughStyle ↔ IOSNSUnderlineStyle?
The strikethrough style of the text.
getter/setter pair
string ↔ String
The characters for the new object.
getter/setter pair
strokeColor ↔ Color?
The color of the stroke.
getter/setter pair
strokeWidth ↔ double?
The width of the stroke.
getter/setter pair
textEffect ↔ IOSNSAttributedStringTextEffectStyle?
The text effect.
getter/setter pair
underlineColor ↔ Color?
The color of the underline.
getter/setter pair
underlineStyle ↔ IOSNSUnderlineStyle?
The underline style of the text.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts instance to a map.
toMap() → Map<String, dynamic>
Converts instance to a map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic>? map) → IOSNSAttributedString?
Gets a possible IOSNSAttributedString instance from a Map value.