IOSNavigationResponseAction class

Class that is used by PlatformWebViewCreationParams.onNavigationResponse event. It represents the policy to pass back to the decision handler. Use NavigationResponseAction instead.

Annotations
  • @Deprecated('Use NavigationResponseAction instead')

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int
Gets int native value.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

values → Set<IOSNavigationResponseAction>
Set of all values of IOSNavigationResponseAction.
final

Static Methods

fromNativeValue(int? value) → IOSNavigationResponseAction?
Gets a possible IOSNavigationResponseAction instance from a native value.
fromValue(int? value) → IOSNavigationResponseAction?
Gets a possible IOSNavigationResponseAction instance from int value.

Constants

ALLOW → const IOSNavigationResponseAction
Allow the navigation to continue.
CANCEL → const IOSNavigationResponseAction
Cancel the navigation.