IOSSslError class

Class that represents the iOS-specific primary error associated to the server SSL certificate. Used by the ServerTrustChallenge class. Use SslErrorType instead.

Annotations

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int
Gets int native value.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

values → Set<IOSSslError>
Set of all values of IOSSslError.
final

Static Methods

fromNativeValue(int? value) → IOSSslError?
Gets a possible IOSSslError instance from a native value.
fromValue(int? value) → IOSSslError?
Gets a possible IOSSslError instance from int value.

Constants

DENY → const IOSSslError
Indicates a user-configured deny; do not proceed.
FATAL_TRUST_FAILURE → const IOSSslError
Indicates a trust failure which cannot be overridden by the user.
INVALID → const IOSSslError
Indicates an invalid setting or result.
OTHER_ERROR → const IOSSslError
Indicates a failure other than that of trust evaluation.
RECOVERABLE_TRUST_FAILURE → const IOSSslError
Indicates a trust policy failure which can be overridden by the user.
UNSPECIFIED → const IOSSslError
Indicates the evaluation succeeded and the certificate is implicitly trusted, but user intent was not explicitly specified.