InAppBrowserClassOptions class

Class that represents the options that can be used for an InAppBrowser WebView. Use InAppBrowserClassSettings instead.

Annotations
  • @Deprecated('Use InAppBrowserClassSettings instead')

Constructors

InAppBrowserClassOptions({InAppBrowserOptions? crossPlatform, AndroidInAppBrowserOptions? android, IOSInAppBrowserOptions? ios, InAppWebViewGroupOptions? inAppWebViewGroupOptions})

Properties

android ↔ AndroidInAppBrowserOptions
Android-specific options.
getter/setter pair
crossPlatform ↔ InAppBrowserOptions
Cross-platform options.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inAppWebViewGroupOptions ↔ InAppWebViewGroupOptions
WebView options.
getter/setter pair
ios ↔ IOSInAppBrowserOptions
iOS-specific options.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copy() → InAppBrowserClassOptions
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic> options) → InAppBrowserClassOptions