InAppBrowserClassSettings class

Class that represents the settings that can be used for an InAppBrowser instance.

Constructors

InAppBrowserClassSettings({InAppBrowserSettings? browserSettings, InAppWebViewSettings? webViewSettings})
InAppBrowserClassSettings.fromMap(Map<String, dynamic> options, {InAppBrowserClassSettings? instance})
factory

Properties

browserSettings ↔ InAppBrowserSettings
Browser settings.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
webViewSettings ↔ InAppWebViewSettings
WebView settings.
getter/setter pair

Methods

copy() → InAppBrowserClassSettings
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited