InAppWebViewGroupOptions class

Class that represents the options that can be used for a WebView. Use InAppWebViewSettings instead.

Annotations

Properties

android ↔ AndroidInAppWebViewOptions
Android-specific options.
getter/setter pair
crossPlatform ↔ InAppWebViewOptions
Cross-platform options.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ios ↔ IOSInAppWebViewOptions
iOS-specific options.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copy() → InAppWebViewGroupOptions
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic> options) → InAppWebViewGroupOptions