InAppWebViewHitTestResultType class

Class representing the InAppWebViewHitTestResult type.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int
Gets int native value.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

values → Set<InAppWebViewHitTestResultType>
Set of all values of InAppWebViewHitTestResultType.
final

Static Methods

fromNativeValue(int? value) → InAppWebViewHitTestResultType?
Gets a possible InAppWebViewHitTestResultType instance from a native value.
fromValue(int? value) → InAppWebViewHitTestResultType?
Gets a possible InAppWebViewHitTestResultType instance from int value.

Constants

EDIT_TEXT_TYPE → const InAppWebViewHitTestResultType
InAppWebViewHitTestResult for hitting an edit text area.
EMAIL_TYPE → const InAppWebViewHitTestResultType
InAppWebViewHitTestResult for hitting an email address.
GEO_TYPE → const InAppWebViewHitTestResultType
InAppWebViewHitTestResult for hitting a map address.
IMAGE_TYPE → const InAppWebViewHitTestResultType
InAppWebViewHitTestResult for hitting an HTML::img tag.
PHONE_TYPE → const InAppWebViewHitTestResultType
InAppWebViewHitTestResult for hitting a phone number.
SRC_ANCHOR_TYPE → const InAppWebViewHitTestResultType
InAppWebViewHitTestResult for hitting a HTML::a tag with src=http.
SRC_IMAGE_ANCHOR_TYPE → const InAppWebViewHitTestResultType
InAppWebViewHitTestResult for hitting a HTML::a tag with src=http + HTML::img.
UNKNOWN_TYPE → const InAppWebViewHitTestResultType
Default InAppWebViewHitTestResult, where the target is unknown.