InAppWebViewPlatform class abstract

Interface for a platform implementation of a WebView.

Inheritance
  • Object
  • PlatformInterface
  • InAppWebViewPlatform

Constructors

InAppWebViewPlatform()
Creates a new InAppWebViewPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createPlatformAssetsPathHandler(PlatformAssetsPathHandlerCreationParams params) → PlatformAssetsPathHandler
Creates a new PlatformAssetsPathHandler.
createPlatformChromeSafariBrowser(PlatformChromeSafariBrowserCreationParams params) → PlatformChromeSafariBrowser
Creates a new PlatformChromeSafariBrowser.
createPlatformChromeSafariBrowserStatic() → PlatformChromeSafariBrowser
Creates a new empty PlatformChromeSafariBrowser to access static methods.
createPlatformCookieManager(PlatformCookieManagerCreationParams params) → PlatformCookieManager
Creates a new PlatformCookieManager.
createPlatformCustomPathHandler(PlatformCustomPathHandlerCreationParams params) → PlatformCustomPathHandler
Creates a new PlatformCustomPathHandler.
createPlatformFindInteractionController(PlatformFindInteractionControllerCreationParams params) → PlatformFindInteractionController
Creates a new PlatformFindInteractionController.
createPlatformHeadlessInAppWebView(PlatformHeadlessInAppWebViewCreationParams params) → PlatformHeadlessInAppWebView
Creates a new PlatformHeadlessInAppWebView.
createPlatformHttpAuthCredentialDatabase(PlatformHttpAuthCredentialDatabaseCreationParams params) → PlatformHttpAuthCredentialDatabase
Creates a new PlatformHttpAuthCredentialDatabase.
createPlatformInAppBrowser(PlatformInAppBrowserCreationParams params) → PlatformInAppBrowser
Creates a new PlatformInAppBrowser.
createPlatformInAppBrowserStatic() → PlatformInAppBrowser
Creates a new empty PlatformInAppBrowser to access static methods.
createPlatformInAppLocalhostServer(PlatformInAppLocalhostServerCreationParams params) → PlatformInAppLocalhostServer
Creates a new empty PlatformInAppLocalhostServer to access static methods.
createPlatformInAppWebViewController(PlatformInAppWebViewControllerCreationParams params) → PlatformInAppWebViewController
Creates a new PlatformInAppWebViewController.
createPlatformInAppWebViewControllerStatic() → PlatformInAppWebViewController
Creates a new empty PlatformInAppWebViewController to access static methods.
createPlatformInAppWebViewWidget(PlatformInAppWebViewWidgetCreationParams params) → PlatformInAppWebViewWidget
Creates a new PlatformInAppWebViewWidget.
createPlatformInternalStoragePathHandler(PlatformInternalStoragePathHandlerCreationParams params) → PlatformInternalStoragePathHandler
Creates a new PlatformInternalStoragePathHandler.
createPlatformJavaScriptReplyProxy(PlatformJavaScriptReplyProxyCreationParams params) → PlatformJavaScriptReplyProxy
Creates a new PlatformJavaScriptReplyProxy.
createPlatformLocalStorage(PlatformLocalStorageCreationParams params) → PlatformLocalStorage
Creates a new PlatformLocalStorage.
createPlatformPrintJobController(PlatformPrintJobControllerCreationParams params) → PlatformPrintJobController
Creates a new PlatformPrintJobController.
createPlatformProcessGlobalConfig(PlatformProcessGlobalConfigCreationParams params) → PlatformProcessGlobalConfig
Creates a new PlatformProcessGlobalConfig.
createPlatformProxyController(PlatformProxyControllerCreationParams params) → PlatformProxyController
Creates a new PlatformProxyController.
createPlatformPullToRefreshController(PlatformPullToRefreshControllerCreationParams params) → PlatformPullToRefreshController
Creates a new PlatformPullToRefreshController.
createPlatformResourcesPathHandler(PlatformResourcesPathHandlerCreationParams params) → PlatformResourcesPathHandler
Creates a new PlatformResourcesPathHandler.
createPlatformServiceWorkerController(PlatformServiceWorkerControllerCreationParams params) → PlatformServiceWorkerController
Creates a new PlatformServiceWorkerController.
createPlatformServiceWorkerControllerStatic() → PlatformServiceWorkerController
Creates a new empty PlatformServiceWorkerController to access static methods.
createPlatformSessionStorage(PlatformSessionStorageCreationParams params) → PlatformSessionStorage
Creates a new PlatformSessionStorage.
createPlatformTracingController(PlatformTracingControllerCreationParams params) → PlatformTracingController
Creates a new PlatformTracingController.
createPlatformWebAuthenticationSession(PlatformWebAuthenticationSessionCreationParams params) → PlatformWebAuthenticationSession
Creates a new PlatformWebAuthenticationSession.
createPlatformWebAuthenticationSessionStatic() → PlatformWebAuthenticationSession
Creates a new empty PlatformWebAuthenticationSession to access static methods.
createPlatformWebMessageChannel(PlatformWebMessageChannelCreationParams params) → PlatformWebMessageChannel
Creates a new PlatformWebMessageChannel.
createPlatformWebMessageChannelStatic() → PlatformWebMessageChannel
Creates a new empty PlatformWebMessageChannel to access static methods.
createPlatformWebMessageListener(PlatformWebMessageListenerCreationParams params) → PlatformWebMessageListener
Creates a new PlatformWebMessageListener.
createPlatformWebMessagePort(PlatformWebMessagePortCreationParams params) → PlatformWebMessagePort
Creates a new PlatformWebMessagePort.
createPlatformWebStorage(PlatformWebStorageCreationParams params) → PlatformWebStorage
Creates a new PlatformWebStorage.
createPlatformWebStorageManager(PlatformWebStorageManagerCreationParams params) → PlatformWebStorageManager
Creates a new PlatformWebStorageManager.
createPlatformWebViewEnvironment(PlatformWebViewEnvironmentCreationParams params) → PlatformWebViewEnvironment
Creates a new PlatformWebViewEnvironment.
createPlatformWebViewEnvironmentStatic() → PlatformWebViewEnvironment
Creates a new empty PlatformWebViewEnvironment to access static methods.
createPlatformWebViewFeature(PlatformWebViewFeatureCreationParams params) → PlatformWebViewFeature
Creates a new PlatformWebViewFeature.
createPlatformWebViewFeatureStatic() → PlatformWebViewFeature
Creates a new empty PlatformWebViewFeature to access static methods.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ InAppWebViewPlatform?
The instance of InAppWebViewPlatform to use.
getter/setter pair