InAppWebViewRect class

A class that represents a structure that contains the location and dimensions of a rectangle.

Constructors

InAppWebViewRect({required double x, required double y, required double width, required double height})

Properties

hashCode → int
The hash code for this object.
no setterinherited
height ↔ double
rect height
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width ↔ double
rect width
getter/setter pair
x ↔ double
x position
getter/setter pair
y ↔ double
y position
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts instance to a map.
toMap() → Map<String, dynamic>
Converts instance to a map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic>? map) → InAppWebViewRect?
Gets a possible InAppWebViewRect instance from a Map value.