JsAlertResponse class

Class that represents the response used by the PlatformWebViewCreationParams.onJsAlert event to control a JavaScript alert dialog.

Constructors

JsAlertResponse({JsAlertResponseAction? action = JsAlertResponseAction.CONFIRM, String confirmButtonTitle = "", bool handledByClient = false, String message = ""})

Properties

action ↔ JsAlertResponseAction?
Action used to confirm that the user hit confirm button.
getter/setter pair
confirmButtonTitle ↔ String
Title of the confirm button.
getter/setter pair
handledByClient ↔ bool
Whether the client will handle the alert dialog.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
message ↔ String
Message to be displayed in the window.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts instance to a map.
toMap() → Map<String, dynamic>
Converts instance to a map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic>? map) → JsAlertResponse?
Gets a possible JsAlertResponse instance from a Map value.