JsAlertResponseAction class

Class used by JsAlertResponse class.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int
Gets int native value.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

values → Set<JsAlertResponseAction>
Set of all values of JsAlertResponseAction.
final

Static Methods

fromNativeValue(int? value) → JsAlertResponseAction?
Gets a possible JsAlertResponseAction instance from a native value.
fromValue(int? value) → JsAlertResponseAction?
Gets a possible JsAlertResponseAction instance from int value.

Constants

CONFIRM → const JsAlertResponseAction
Confirm that the user hit confirm button.