NavigationResponse class

Class that represents the navigation response used by the PlatformWebViewCreationParams.onNavigationResponse event.

Constructors

Properties

canShowMIMEType ↔ bool
A Boolean value that indicates whether WebKit is capable of displaying the response’s MIME type natively.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isForMainFrame ↔ bool
A Boolean value that indicates whether the response targets the web view’s main frame.
getter/setter pair
response ↔ URLResponse?
The URL for the response.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts instance to a map.
toMap() → Map<String, dynamic>
Converts instance to a map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic>? map) → NavigationResponse?
Gets a possible NavigationResponse instance from a Map value.