NavigationType class

Class that represents the type of action triggering a navigation for the PlatformWebViewCreationParams.shouldOverrideUrlLoading event.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int?
Gets int? native value.
toString() → String
A string representation of this object.
override
toValue() → String
Gets String value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

BACK_FORWARD → NavigationType
An item from the back-forward list was requested.
final
FORM_RESUBMITTED → NavigationType
A form was resubmitted (for example by going back, going forward, or reloading).
final
FORM_SUBMITTED → NavigationType
A form was submitted.
final
A link with an href attribute was activated by the user.
final
OTHER → NavigationType
Navigation is taking place for some other reason.
final
RELOAD → NavigationType
The webpage was reloaded.
final
values → Set<NavigationType>
Set of all values of NavigationType.
final

Static Methods

fromNativeValue(int? value) → NavigationType?
Gets a possible NavigationType instance from a native value.
fromValue(String? value) → NavigationType?
Gets a possible NavigationType instance from String value.