PathHandler class abstract

A handler that produces responses for a registered path.

Implement this interface to handle other use-cases according to your app's needs.

Implemented types
Implementers

Constructors

PathHandler.fromPlatform({required PlatformPathHandler platform})
Constructs a PathHandler from a specific platform implementation.

Properties

eventHandler ↔ PlatformPathHandlerEvents?
Event handler object that handles the PlatformPathHandler events.
latefinaloverride
hashCode → int
The hash code for this object.
no setterinherited
path → String
The suffix path to be handled.
no setteroverride
platform → PlatformPathHandler
Implementation of PlatformPathHandler for the current platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
The path handler type.
no setteroverride

Methods

handle(String path) → Future<WebResourceResponse?>
Handles the requested URL by returning the appropriate response.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited