PlatformFindInteractionControllerCreationParams class

Object specifying creation parameters for creating a PlatformFindInteractionController.

Platform specific implementations can add additional fields by extending this class.

Annotations

Constructors

PlatformFindInteractionControllerCreationParams({void onFindResultReceived(PlatformFindInteractionController controller, int activeMatchOrdinal, int numberOfMatches, bool isDoneCounting)?})
Used by the platform implementation to create a new PlatformFindInteractionController.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
onFindResultReceived → void Function(PlatformFindInteractionController controller, int activeMatchOrdinal, int numberOfMatches, bool isDoneCounting)?
Event fired as find-on-page operations progress. The listener may be notified multiple times while the operation is underway, and the numberOfMatches value should not be considered final unless isDoneCounting is true.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited