PlatformPathHandler class abstract

A handler that produces responses for a registered path.

Implement this interface to handle other use-cases according to your app's needs.

Implementers

Constructors

PlatformPathHandler()

Properties

eventHandler ↔ PlatformPathHandlerEvents?
Event handler object that handles the PlatformPathHandler events.
latefinal
hashCode → int
The hash code for this object.
no setterinherited
path → String
The suffix path to be handled.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
The path handler type.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited