PlatformWebStorage class abstract

Class that provides access to the JavaScript Web Storage API: window.sessionStorage and window.localStorage. It used by PlatformInAppWebViewController.webStorage.

Officially Supported Platforms/Implementations:

  • Android native WebView
  • iOS
  • MacOS
  • Web
  • Windows
Inheritance
  • Object
  • PlatformInterface
  • PlatformWebStorage
Implemented types

Constructors

PlatformWebStorage(PlatformWebStorageCreationParams params)
Creates a new PlatformWebStorage
factory
PlatformWebStorage.implementation(PlatformWebStorageCreationParams params)
Used by the platform implementation to create a new PlatformWebStorage.

Properties

hashCode → int
The hash code for this object.
no setterinherited
localStorage → PlatformLocalStorage
Represents window.localStorage.
no setter
params → PlatformWebStorageCreationParams
The parameters used to initialize the PlatformWebStorage.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionStorage → PlatformSessionStorage
Represents window.sessionStorage.
no setter

Methods

dispose() → void
Disposes the web storage.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited