PlatformWebViewFeature class abstract

Class that represents an Android-specific utility class for checking which WebView Support Library features are supported on the device.

Officially Supported Platforms/Implementations:

  • Android native WebView
Inheritance
  • Object
  • PlatformInterface
  • PlatformWebViewFeature

Constructors

PlatformWebViewFeature(PlatformWebViewFeatureCreationParams params)
Creates a new PlatformWebViewFeature
factory
PlatformWebViewFeature.implementation(PlatformWebViewFeatureCreationParams params)
Used by the platform implementation to create a new PlatformWebViewFeature.
PlatformWebViewFeature.static()
Creates a new empty PlatformWebViewFeature to access static methods.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
params → PlatformWebViewFeatureCreationParams
The parameters used to initialize the PlatformWebViewFeature.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isFeatureSupported(WebViewFeature feature) → Future<bool>
Return whether a feature is supported at run-time. On devices running Android version Build.VERSION_CODES.LOLLIPOP and higher, this will check whether a feature is supported, depending on the combination of the desired feature, the Android version of device, and the WebView APK on the device. If running on a device with a lower API level, this will always return false.
isStartupFeatureSupported(WebViewFeature startupFeature) → Future<bool>
Return whether a startup feature is supported at run-time. On devices running Android version Build.VERSION_CODES.LOLLIPOP and higher, this will check whether a startup feature is supported, depending on the combination of the desired feature, the Android version of device, and the WebView APK on the device. If running on a device with a lower API level, this will always return false.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited