PrintJobPageOrder class

Class representing the page order that will be used to generate the pages of a PlatformPrintJobController.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int
Gets int native value.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

ASCENDING → PrintJobPageOrder
Ascending (back to front) page order.
final
DESCENDING → PrintJobPageOrder
Descending (front to back) page order.
final
SPECIAL → PrintJobPageOrder
The spooler does not rearrange pages—they are printed in the order received by the spooler.
final
UNKNOWN → PrintJobPageOrder
No page order specified.
final
values → Set<PrintJobPageOrder>
Set of all values of PrintJobPageOrder.
final

Static Methods

fromNativeValue(int? value) → PrintJobPageOrder?
Gets a possible PrintJobPageOrder instance from a native value.
fromValue(int? value) → PrintJobPageOrder?
Gets a possible PrintJobPageOrder instance from int value.