PrintJobState class

Class representing the state of a PlatformPrintJobController.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int?
Gets int? native value.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

BLOCKED → PrintJobState
Print job state: The print job is blocked.
final
CANCELED → PrintJobState
Print job state: The print job is canceled. This is a terminal state.
final
COMPLETED → PrintJobState
Print job state: The print job is successfully printed. This is a terminal state.
final
CREATED → PrintJobState
Print job state: The print job is being created but not yet ready to be printed.
final
FAILED → PrintJobState
Print job state: The print job was printing but printing failed.
final
QUEUED → PrintJobState
Print job state: The print jobs is created, it is ready to be printed and should be processed.
final
STARTED → PrintJobState
Print job state: The print job is being printed.
final
values → Set<PrintJobState>
Set of all values of PrintJobState.
final

Static Methods

fromNativeValue(int? value) → PrintJobState?
Gets a possible PrintJobState instance from a native value.
fromValue(int? value) → PrintJobState?
Gets a possible PrintJobState instance from int value.