PullToRefreshSize class

Class representing the size of the refresh indicator.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int
Gets int native value.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

values → Set<PullToRefreshSize>
Set of all values of PullToRefreshSize.
final

Static Methods

fromNativeValue(int? value) → PullToRefreshSize?
Gets a possible PullToRefreshSize instance from a native value.
fromValue(int? value) → PullToRefreshSize?
Gets a possible PullToRefreshSize instance from int value.

Constants

DEFAULT → const PullToRefreshSize
Default size.
LARGE → const PullToRefreshSize
Large size.