SafeBrowsingResponse class

Class that represents the response used by the PlatformWebViewCreationParams.onSafeBrowsingHit event. It is used to indicate an action to take when hitting a malicious URL.

Constructors

SafeBrowsingResponse({SafeBrowsingResponseAction? action = SafeBrowsingResponseAction.SHOW_INTERSTITIAL, bool report = true})

Properties

action ↔ SafeBrowsingResponseAction?
Indicate the SafeBrowsingResponseAction to take when hitting a malicious URL.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
report ↔ bool
If reporting is enabled, all reports will be sent according to the privacy policy referenced by PlatformInAppWebViewController.getSafeBrowsingPrivacyPolicyUrl.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts instance to a map.
toMap() → Map<String, dynamic>
Converts instance to a map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic>? map) → SafeBrowsingResponse?
Gets a possible SafeBrowsingResponse instance from a Map value.