SelectionGranularity class

Class used to set the level of granularity with which the user can interactively select content in the web view.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int
Gets int native value.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

values → Set<SelectionGranularity>
Set of all values of SelectionGranularity.
final

Static Methods

fromNativeValue(int? value) → SelectionGranularity?
Gets a possible SelectionGranularity instance from a native value.
fromValue(int? value) → SelectionGranularity?
Gets a possible SelectionGranularity instance from int value.

Constants

CHARACTER → const SelectionGranularity
Selection endpoints can be placed at any character boundary.
DYNAMIC → const SelectionGranularity
Selection granularity varies automatically based on the selection.