ServerTrustAuthResponseAction class

Class used by ServerTrustAuthResponse class.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int
Gets int native value.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

values → Set<ServerTrustAuthResponseAction>
Set of all values of ServerTrustAuthResponseAction.
final

Static Methods

fromNativeValue(int? value) → ServerTrustAuthResponseAction?
Gets a possible ServerTrustAuthResponseAction instance from a native value.
fromValue(int? value) → ServerTrustAuthResponseAction?
Gets a possible ServerTrustAuthResponseAction instance from int value.

Constants

CANCEL → const ServerTrustAuthResponseAction
Instructs the WebView to cancel the authentication challenge.
PROCEED → const ServerTrustAuthResponseAction
Instructs the WebView to proceed with the authentication challenge.