URLProtectionSpaceProxyType class

Class that represents the supported proxy types.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → String
Gets String native value.
toString() → String
A string representation of this object.
override
toValue() → String
Gets String value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

values → Set<URLProtectionSpaceProxyType>
Set of all values of URLProtectionSpaceProxyType.
final

Static Methods

fromNativeValue(String? value) → URLProtectionSpaceProxyType?
Gets a possible URLProtectionSpaceProxyType instance from a native value.
fromValue(String? value) → URLProtectionSpaceProxyType?
Gets a possible URLProtectionSpaceProxyType instance from String value.

Constants

URL_PROTECTION_SPACE_FTP_PROXY → const URLProtectionSpaceProxyType
The proxy type for FTP proxies.
URL_PROTECTION_SPACE_HTTP_PROXY → const URLProtectionSpaceProxyType
The proxy type for HTTP proxies.
URL_PROTECTION_SPACE_HTTPS_PROXY → const URLProtectionSpaceProxyType
The proxy type for HTTPS proxies.
URL_PROTECTION_SPACE_SOCKS_PROXY → const URLProtectionSpaceProxyType
The proxy type for SOCKS proxies.