URLRequestAttribution class

Class that represents the constants used to indicate the entities that can make a network request.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int
Gets int native value.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

values → Set<URLRequestAttribution>
Set of all values of URLRequestAttribution.
final

Static Methods

fromNativeValue(int? value) → URLRequestAttribution?
Gets a possible URLRequestAttribution instance from a native value.
fromValue(int? value) → URLRequestAttribution?
Gets a possible URLRequestAttribution instance from int value.

Constants

DEVELOPER → const URLRequestAttribution
A developer-initiated network request.
USER → const URLRequestAttribution
Use this value for the attribution parameter of a URLRequest that satisfies a user request to access an explicit, unmodified URL. In all other cases, use the URLRequestAttribution.DEVELOPER value instead.