WebHistory class

This class contains a snapshot of the current back/forward list for a WebView.

Constructors

WebHistory({int? currentIndex, List<WebHistoryItem>? list})

Properties

currentIndex ↔ int?
Index of the current WebHistoryItem.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
list ↔ List<WebHistoryItem>?
List of all WebHistoryItems.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts instance to a map.
toMap() → Map<String, dynamic>
Converts instance to a map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic>? map) → WebHistory?
Gets a possible WebHistory instance from a Map value.