WebMessage class

The Dart representation of the HTML5 PostMessage event. See https://html.spec.whatwg.org/multipage/comms.html#the-messageevent-interfaces for definition of a MessageEvent in HTML5.

Constructors

WebMessage({dynamic data, WebMessageType type = WebMessageType.STRING, List<IWebMessagePort>? ports})

Properties

data ↔ dynamic
The data of the message.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ports ↔ List<IWebMessagePort>?
The ports that are sent with the message.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ WebMessageType
The payload type of the message.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts instance to a map.
toMap() → Map<String, dynamic>
Converts instance to a map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic>? map) → WebMessage?
Gets a possible WebMessage instance from a Map value.