WebMessageType class

The type corresponding to the WebMessage.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int
Gets int native value.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

values → Set<WebMessageType>
Set of all values of WebMessageType.
final

Static Methods

fromNativeValue(int? value) → WebMessageType?
Gets a possible WebMessageType instance from a native value.
fromValue(int? value) → WebMessageType?
Gets a possible WebMessageType instance from int value.

Constants

ARRAY_BUFFER → const WebMessageType
Indicates the payload of WebMessageCompat is JavaScript ArrayBuffer.
STRING → const WebMessageType
Indicates the payload of WebMessageCompat is String.