WebStorageItem class

Class that represents a single web storage item of the JavaScript window.sessionStorage and window.localStorage objects.

Constructors

WebStorageItem({String? key, dynamic value})

Properties

hashCode → int
The hash code for this object.
no setterinherited
key ↔ String?
Item key.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ dynamic
Item value.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts instance to a map.
toMap() → Map<String, dynamic>
Converts instance to a map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic>? map) → WebStorageItem?
Gets a possible WebStorageItem instance from a Map value.