WebViewEnvironment class

Constructors

WebViewEnvironment.fromPlatform({required PlatformWebViewEnvironment platform})
Constructs a WebViewEnvironment from a specific platform implementation.
WebViewEnvironment.fromPlatformCreationParams({required PlatformWebViewEnvironmentCreationParams params})
Constructs a WebViewEnvironment.

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String
WebView Environment ID.
no setter
platform → PlatformWebViewEnvironment
Implementation of PlatformWebViewEnvironment for the current platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settings → WebViewEnvironmentSettings?
WebView Environment settings.
no setter

Methods

dispose() → Future<void>
Disposes the WebView Environment reference.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

compareBrowserVersions({required String version1, required String version2}) → Future<int?>
Get the browser version info including channel name if it is not the WebView2 Runtime.
create({WebViewEnvironmentSettings? settings}) → Future<WebViewEnvironment>
Creates the PlatformWebViewEnvironment using settings.
getAvailableVersion({String? browserExecutableFolder}) → Future<String?>
Get the browser version info including channel name if it is not the WebView2 Runtime.