WebViewRenderProcessAction class

Class that represents the action to take used by the PlatformWebViewCreationParams.onRenderProcessUnresponsive and PlatformWebViewCreationParams.onRenderProcessResponsive event to terminate the Android WebViewRenderProcess.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int
Gets int native value.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

values → Set<WebViewRenderProcessAction>
Set of all values of WebViewRenderProcessAction.
final

Static Methods

fromNativeValue(int? value) → WebViewRenderProcessAction?
Gets a possible WebViewRenderProcessAction instance from a native value.
fromValue(int? value) → WebViewRenderProcessAction?
Gets a possible WebViewRenderProcessAction instance from int value.

Constants

TERMINATE → const WebViewRenderProcessAction
Cause this renderer to terminate.