WindowTitlebarSeparatorStyle class

Class that represents the type of separator that the app displays between the title bar and content of a browser window.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int?
Gets int? native value.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

AUTOMATIC → WindowTitlebarSeparatorStyle
A style indicating that the system determines the type of separator.
final
LINE → WindowTitlebarSeparatorStyle
A style indicating that there’s no title bar separator.
final
NONE → WindowTitlebarSeparatorStyle
A style indicating that the title bar separator is a line.
final
SHADOW → WindowTitlebarSeparatorStyle
A style indicating that the title bar separator is a shadow.
final
values → Set<WindowTitlebarSeparatorStyle>
Set of all values of WindowTitlebarSeparatorStyle.
final

Static Methods

fromNativeValue(int? value) → WindowTitlebarSeparatorStyle?
Gets a possible WindowTitlebarSeparatorStyle instance from a native value.
fromValue(int? value) → WindowTitlebarSeparatorStyle?
Gets a possible WindowTitlebarSeparatorStyle instance from int value.